The new seven wonders: Defining the top technological marvels of the contemporary age.
Description: The seven wonders of classical antiquity were architectural marvels, triumphs of human ego and raw power. The great achievements of today, however, are made possible by systems, infrastructure, and technologies that are invisible. Check back every week for a new wonder of the modern world. When the weather is...
Keywords: SEA-ME-3, undersea cables, fiber-optic cables, 7 wonders of modern age, 7 wonders of contemporary age, faa, us air traffic control, us aviation control, air safety, us air safety statistics, national transportation safety board stats, faa next gen project, automatic dependent surveillance broadcast, wake recategorization, waze, GPS, global positioning systems, maps, highways, traffic

1 The U.S. Aviation Control System

The seven wonders of classical antiquity were architectural marvels, triumphs of human ego and raw power. The great achievements of today, however, are made possible by systems, infrastructure, and technologies that are invisible. Check back every week for a new wonder of the modern world.

When the weather is clear and all systems are go, as many as 3,100 flights can take off and land each day at Hartsfield-Jackson Atlanta International, the busiest airport in the world. In recent years, the airport has expanded its flight capacity slightly, but not by increasing the number of runways. Watch the planes take off, and you might see a more subtle innovation.

Because air traffic controllers are now monitoring departing aircraft with GPS-based systems rather than radar, the planes follow much more precise and predictable paths—some straight ahead, others instead banking several degrees to the left or right. This more accurate tracking lets controllers release more planes for takeoff into the same airspace while maintaining the required separation distance of 3 horizontal miles and 1,000 vertical feet. By halving the time to clear the next flight for departure on some runways from two minutes to one, Atlanta controllers can now put as many as 12 more planes per hour into the heavens.

In many ways, flying has become an unpleasant, increasingly expensive, and frequently contentious effort. America’s airports feel like glorified bus stations in comparison to the sleek terminals of Asia and the Middle East. The consumer interface of air travel—bag charges, humiliating security procedures, $8 stale sandwiches, evaporating leg room—can seem as frenzied and dreadful as a Hieronymus Bosch painting.

But the carefully choreographed diversions on Atlanta’s runways, which shave just seconds off flights, are, in their own subtle way, as graceful as the Hanging Gardens of Babylon and as awe-inspiring as the Colossus of Rhodes. They’re one of the many remarkable aspects of an air-control regime that most people never notice—a system that is one of the marvels of the modern world.

Animation by Lisa Larson-Walker

This series will explore seven of these new wonders: bewildering achievements, incredibly useful tools and services that we take for granted. None of them is monumental in scale, like the seven wonders of classical antiquity chronicled by Antipater of Sidon more than 2,000 years ago. The Great Pyramids of Giza and the Statue of Zeus at Olympia were feats of engineering, triumphs of man over nature and gravity, and above all accomplishments of ego and raw power. And the modern, man-made wonders we marvel at—the Brooklyn Bridge, the Hoover Dam, the Panama Canal—are echoes of the ancient ones: breathtaking physical manifestations of human ingenuity. Today’s wonders, in contrast, aren’t so in your face. Instead, they’re powered and made possible by systems, infrastructure, and technologies that are often invisible. The Lighthouse of Alexandria was a triumph of front-end, or consumer-facing, engineering, to use a Web developer’s terminology. But today’s innovations, insights, and wonders can just as frequently be found in the back end, where we rarely notice them.

Like the ancient wonders, this list is somewhat arbitrary. But there is a method to it. Sure, the world is filled with new, man-made wonders of an astounding scale, like the CCTV headquarters in Beijing and the Three Gorges Dam. But monumental buildings and dams have been done before, even millennia ago. Today, the point of buildings and infrastructure shouldn’t be to impress but to connect. In the 21st century, our ability to thrive rests in large measure on the quality and power of the networks that transport data, information, and life-giving substances like water. Part of this series’s goal is to highlight systems that are overlooked or maligned yet remain both extraordinarily functional and vital to the daily lives of hundreds of millions of people.

That’s certainly the case with the U.S. aviation control system. With land and infrastructure dollars hard to come by, subtle upgrades to the operating system are effectively increasing the capacity of our airports and skies, making it all run more smoothly and safely.

In the U.S., air travel is a form of mass transit, so these efficiency improvements matter a great deal. In 2013, there were 21.58 million commercial flights, according to the Federal Aviation Administration. And serious glitches, on the ground and in the skies, have become more rare. Between 2007 and 2013, the likelihood of a piece of luggage being mislaid fell by more than half—from a rate of 7.03 per 1,000 passengers to 3.22 per 1,000, as the Wall Street Journal reported. (That, in turn, is less than half the global rate of 6.96 per 1,000.)

The global system, of course, is far from foolproof, as the lost Malaysia Airlines Flight 370 and its cousin shot down over the Ukraine made clear earlier this year. But in the U.S., the world’s busiest airspace, safety has improved dramatically. According to National Transportation Safety Board data, between 1994 and 2006 there were only two years in which no fatalities were recorded on scheduled commercial domestic flights. But in six of the last seven years, and in each of the past four, there have been none. Between 2010 and 2013, there were 2.94 billion passenger emplanements on scheduled commercial flights—about 735 million annually. All those people reached their destinations alive, with just 12 injuries. (The 2009 Colgan Air crash outside Buffalo, New York, which killed 50 people, was the last major commercial disaster within our borders. There have been several fatal crashes involving cargo or chartered planes.*)

Animation by Lisa Larson-Walker

The air traffic control system—the ground-based radar installations, the onboard navigation devices, the 264 FAA towers, and the software and networks that connect them and manage the movement of planes—actually works remarkably well, even if widespread delays and cancellations sometimes lead us to curse the entire mode of transportation instead of marveling, as we once did, at the triumph of human flight. Traveling the skies may no longer feel like a miracle, but the systems that make it possible and increasingly more efficient deserve our adulation. Slowly, imperceptibly, and often invisibly, the FAA is rolling out what it calls the NextGen project, an alphabet soup of acronyms that describe a set of initiatives, procedures, and protocols that are improving the way we fly. “It’s not going to be the sort of thing where we flip a switch,” FAA spokesman Paul Takemoto says. “But we are going to phase out the old system.”

Though sturdy, the legacy system—a network of ground-based radar stations that feed information to controllers, who then communicate with pilots over radio—is like an analog system in an increasingly digital world. Ground-based radar signals degrade over distance and can’t penetrate mountains. The stations can’t be placed on water. And the radar updates only once every 4.7 seconds. All of which requires planes to stay farther apart from one another in the air—clogging up vital air channels—and poses significant challenges in navigating over water, around weather, and in mountainous areas.

Increasingly, though, that’s changing. As part of NextGen, a satellite-based system called Automatic Dependent Surveillance-Broadcast, or ADS-B, will use GPS to locate planes and connect them to air traffic control. By Jan. 1, 2020, all aircraft flying in controlled airspace will be required to have ADS-B equipment. ADS-B is now enabling planes to fly around weather over open water in the Gulf of Mexico—saving time and fuel and sometimes completely sparing passengers from turbulence. And instead of exchanging vital information orally—which ties up radio frequencies and can result in miscommunications—pilots and controllers will rely on powerful data transmission and processing systems. In 2013, introductory programs began in Memphis, Tennessee, and Newark, New Jersey, in which routine communications—clearance to take off, a change in route to avoid a thunderstorm—were effectively delivered to LCD screens via text updates.

There are also smaller, localized fixes. In airports like the Yampa Valley Regional Airport, which services ski areas like Steamboat Springs, Colorado, delays and cancellations play havoc with schedules during the peak season, in large measure because radar isn’t very good at tracking planes as they negotiate mountainous areas. As part of a small-scale experiment, the FAA deployed a bunch of sensors in the area to form a network, called wide area multilateration, that can keep much better tabs on planes. The upshot: Yampa Valley can handle 15 to 20 arrivals safely each hour in conditions that would have previously required planes to be diverted to other airports.

Throughout the air traffic control system, new protocols—based in part on new technology and on research and analysis—effectively expand flight capacity by enabling planes to flow in and out of airports and airspaces more quickly and with fewer hitches. At Boston Logan and other airports, GPS-based systems that allow for more precise tracing of planes mean they can now land when visibility is as low as 1,800 feet—compared with the prior standard of 2,400 feet.

Wake turbulence can be hazardous, with the potential to overturn smaller airplanes without warning.

Photo by Etienne De Malglaive/Gamma-Rapho via Getty Images

At John F. Kennedy Airport in New York, where the traffic on the runways has often rivaled that on the New Jersey Turnpike, controllers are now using a virtual queuing system. By forecasting traffic through historical data, they assign 15-minute slots to flights up to two hours in advance. Rather than leave the gate and sit on the runway, planes wait with their engines off until their appointed times. That saves fuel (since they can run systems on electric power at the gate) and reduces congestion in the taxi areas.

Meanwhile, changes in technology and the addition of smaller jets to America’s aviation fleet have led controllers to re-examine the effects of wake turbulence—the vortexes that planes leave in their wake when they take off. In certain instances, as when smaller jets are in a queue behind aircraft of the same size, the FAA has concluded that it’s safe to let planes begin taking off right after the ones in front of them have left the ground, instead of waiting the traditional three minutes. When it was first tested in Memphis, wake recategorization effectively boosted capacity of runways by up to 20 percent. After controllers in Atlanta started using recategorization in June, it evoked a sense of wonder in the industry. “That is saving a minute or a minute and a half right there,” said Mark Hopkins, Delta’s director of air traffic management. “This is eye-opening.”

Taken individually—a minute saved here, a few hundred of feet of visibility added there, several gallons of fuel conserved somewhere else—these improvements may not seem to add up to much. But just as a small delay in a complex system can lead to further delays, small innovations can have powerful knock-on effects. These incremental fixes, all rolled out with little notice, highlight how our more reliable and efficient aviation system has become a modern marvel. And impressively, the FAA is slowly pushing through its immense upgrades while operating at full-tilt in a highly safe and surprisingly effective manner. That’s like replacing the George Washington Bridge in its entirety without lane closures or new traffic problems.

In an age in which constricted financial resources and geographic footprints prevent us from expanding the physical footprint of airports, the highly resilient and evolving air traffic control system is doing the heavy lifting behind the scenes. We should look up in awe.

With reporting by Laura Bradley.

Check back every week for a new wonder of the modern world.

Correction, Nov. 11, 2014: This article originally stated that 45 people died in the 2009 Colgan Air crash. Forty-five passengers, four crew, and one person on the ground died in that crash. (Return.)

2 The Dynamic Map

The seven wonders of classical antiquity were architectural marvels, triumphs of human ego and raw power. The great achievements of today, however, are made possible by systems, infrastructure, and technologies that are invisible. This series, which began with the U.S. aviation control system, explores the wonders of our modern world. Here is the second wonder:

In the chaotic aftermath of Hurricane Sandy in the autumn of 2012, the Federal Emergency Management Agency had no idea which gas stations were open or closed in the greater New York area. With widespread flooding and electricity outages, and with downed trees blocking roads, there was no way—short of the slow task of dialing up each station—to swiftly determine which ones had gas or even power. So FEMA contacted Waze, a free navigation app that allows users to anonymously post data about traffic incidents and edit maps. Waze sent a push notice to drivers, asking them to share the status of stations in their neighborhoods. The app then updated its maps to show pins on stations that were up and running. After quickly cataloging the information, Waze zapped it to FEMA in an Excel file, which helped the agency effectively dispatch tanker trucks to replenish supplies.

People wait to buy gas in Union City, New Jersey, on Nov. 2, 2012, after Hurricane Sandy slammed the Northeast.

Photo by Eduardo Munoz/Reuters

Waze has grown rapidly since its founding in 2008 by Amir Shinar and Ehud Shabtai, Israeli computer experts who were dissatisfied with the global positioning systems in their cars. When Los Angeles shut down the I-405 in the July 2012 “Carmageddon,” Waze users provided traffic information more effectively than traffic helicopters could. In fall 2012, when Tim Cook publicly apologized for the debacle of Apple Maps, he recommended Waze as an alternative. The service now claims more than 50 million users in 45 languages, in 200 countries. Last year, Google acquired Waze for a price reported at about $1 billion. While big tech companies often buy startups only to absorb their innovations and shutter them, Google has made Waze part of the family. The app has incorporated Google Street View and hired more people, while Google Maps has added Waze data on traffic and street closures.

It might be easier to appreciate today’s browser- and app-based dynamic maps and the systems and devices that power them—Waze and Google Maps, but also Scout, Polaris, TomTom, Garmin, and Magellan—as wonders of the modern world if, like me, you’re old enough to remember when planning a cross-country driving trip meant visiting a AAA office to get a Trip-Tik (a set of highlighted maps). Even with paper maps, in some ways drivers were flying blind. Beyond periodic traffic updates on the radio, there was virtually no real-time information available about road closures, accidents, construction—the phenomena that can turn an easy 15-minute trip into a grinding two-hour ordeal. As recently as a decade ago, a driver departing Montclair, New Jersey, would have no idea whether it made more sense to take the Garden State Parkway or the New Jersey Turnpike.

Maps of San Francisco: 1948 Transportation Plan (via Eric Fischer/Flickr) and 2014 (via Waze)

But in recent years, individuals have been able to tap into the technology that was once the exclusive preserve of the military. Like so many other staples of consumer life—from CorningWare to the Internet—GPS has its origins in Cold War–era military research. After the shock of Sputnik, the Pentagon began working on ways to use orbiting satellites to help fix the positions of submarines and other naval vessels. A network of several satellites in the 1960s, known as Transit, was augmented by the NAVSTAR system, the construction of which began in the 1970s.

Today’s GPS apps and devices reach to the heavens to help us navigate our little corners of the Earth. We can know that traffic is seriously backed up on the southbound lanes of I-95 in Bridgeport, Connecticut, because a car is broken down on the side of the road, that a tow truck has just arrived, and that it makes sense to jump onto Route 1 and then re-enter I-95 a few miles later in Fairfield. These mostly free services are some of the most valuable—but difficult to value—components of the so-called “consumer surplus” that our modern information economy provides.

With its singular combination of technology, human intelligence, and curation, Waze illustrates the awe-inspiring potential of the dynamic map better than any of its competitors. And the attributes that make the app so popular—think Wikipedia or Pinterest, but for traffic and maps—are highly visible. But just like America’s increasingly sophisticated air traffic control system, which I explored in the first part of this series, Waze is a back-end marvel. Unlike the Great Pyramid of Giza or the other seven wonders of antiquity, its most amazing innovations are invisible.

Most GPS-based navigation and traffic apps rely on road cameras and sensors on highly trafficked roads and are updated every five minutes or so. I find it’s not uncommon for me to check out traffic on MapQuest or Google Maps before leaving the house only to find Connecticut’s Merritt Parkway is surprisingly backed up a few minutes later. Waze aims to provide more useful, actionable information by instantly updating data and context—provided by both machines and humans—via a cute, friendly interface. (Of course, as is the case with many free apps and publications, the user experience is occasionally disrupted by pop-up ads.)

Waze’s back end, obviously, includes the network of Google servers, wireless stations, satellites, and software code that powers it. But that’s just the beginning. Massive, open public editing of a site can be a road to misinformation and mischief—just read any Internet comments section or contentious Wikipedia page. Waze overlays its data with a constant stream of user-submitted comments, then runs them through systems it has built to channel and reward human behavior. Then it figures out how to make this system do useful work in the world. All of this happens behind the scenes.

Part of Waze’s back end is passive. When a Waze user turns on a phone and opens the app, Waze pings the phone’s GPS chip every second and recalculates traffic every three minutes. The simple act of driving with the app open turns users into traffic reporters—confirming they are on the road and giving an indication of speed. Scale makes this passive crowdsourcing useful. On an average day in Rio de Janeiro, 110,000 active Waze drivers cover 1.2 million kilometers. The data isn’t just broadcast, however. Waze feeds it into algorithms that enable it to conduct predictive modeling based on past experience. So when somebody maps a prospective route through Rio, Waze can produce suggestions based on reported traffic conditions and on how long it typically takes drivers to negotiate the routes at that time of day. (In an update earlier this year, Google Maps integrated the ability to change routes on the fly in reaction to traffic snarls.)

Part of the appeal of Waze is that users can report incidents—traffic, congestion, a mattress in the road—that instantly generate icons on its maps. On a typical day in Rio, users actively report about 58,000 incidents. But in the back end, not all incident reports are treated equally. Waze has built a system that evaluates users’ capacity, experience, and accuracy, weighing the information they provide accordingly. Like many social apps, Waze allows users the opportunity to give a “thumbs up” or “thumbs down” to posts. Reports by users who frequently file incidents that are routinely confirmed by others will be weighted higher, while Waze gives less trust to people who consistently file false alarms.

Mapping the world and charting its traffic problems are extraordinarily labor-intensive undertakings. That’s where Waze’s human back end comes into play. The company has about 160 employees, divided between Tel Aviv, Israel; New York; and Mountain View, California. But the map—a breathing organism that constantly evolves to ensure the accuracy of street names, housing numbers, and construction sites—is maintained by a community of 200,000 volunteer map editors. Editors—anybody can sign up—start by making notations about their immediate area. “We don’t manage them, we don’t pay them, we don’t tell them what to do,” says Julie Mossler, a Waze spokeswoman. But the company doesn’t have an entirely hands-off attitude. People who have made 1 million edits or more are considered “champs,” and they have a direct line to the company. And Waze now provides support to a group of editors based in Italy who are starting a project to map Africa more accurately.

Traffic moves slowly on the 405 freeway in Los Angeles on July 14, 2011.

Photo by Eric Thayer/Reuters

While Waze could function perfectly well without much human intervention from its headquarters, its competitive advantage and utility arise in part from the relationships its staff cultivates and their ability to inject human intelligence into the system—whether it’s reaching out to Los Angeles authorities during Carmageddon or working with FEMA to generate lists of open gas stations. In early October, when a Waze staffer learned that President Obama was visiting San Francisco, the app sent a push notice to advise users in the area to get out on the roads a little earlier. And the company just set up a partnership—Connected Citizen—in which it will provide traffic data to cities like Tel Aviv; Barcelona, Spain; and San Jose, Costa Rica in exchange for more immediate access to information on issues like road closures or construction. All of which proves that even in a highly wired and automated world, personal and institutional relationships can be a vital part of infrastructure.

Government is supposed to step in during a market failure. But Waze shows how the market can correct for government failure. The app is extremely popular in Costa Rica. Why? In a nation where authorities haven’t bothered to name many roads and streets and paper maps are unreliable, Waze volunteers have effectively functioned as a sort of public agency. In places where the grid has yet to be captured, Waze isn’t an adjunct to maps—it is the map. “Waze has become such a part of the culture that businesses will even list their addresses in advertisements as locations that can be searched for on Waze,” the Washington Post reported recently.

Waze likely won’t be around forever, but its many features, some subtle and some outright mind-bending, suggest that the maps we rely on every day are only going to get more sophisticated, data-rich, and, yes, wondrous. It’s easy to imagine the maps of the future being studded and layered with information on Wi-Fi hot spots, crime data, public transit schedules, and weather. Harry Potter’s Marauder’s Map, which allowed him to see who was scurrying around Hogwarts late at night, will have nothing on the amazing, thoroughly unmagical cartographic apps in our pockets.

Already, as I pull out of my driveway, I can know that traffic is dragging at an 8-mile clip on the Post Road in downtown Westport, Connecticut, which means I should use a back roads cut-through. I can expect that repair teams have arrived for the bridge project on I-95 north, which is keeping traffic running at a pokey 23 miles per hour. And I can prepare to accelerate to above 40 miles per hour right after the underpass—that last tip courtesy of a Waze user whose avatar includes sunglasses and a little sword.

In another era, the sunglasses-and-swords guy might have been adding blocks to the Great Pyramid. These days, he’s contributing to our modern maps’ achievement of near omniscience in a chaotic, ever-changing system.

Check back every week for a new wonder of the modern world.

The seven wonders of classical antiquity were architectural marvels, triumphs of human ego and raw power. The great achievements of today, however, are made possible by systems, infrastructure, and technologies that are invisible. This series, which continued last week with GPS-powered dynamic maps, explores the wonders of our modern world. Here is the third wonder:

3 The Undersea Information Highway

Ever think twice about our superfast data connections? Email accounts. Skype chats. Stock quotes. The latest Taylor Swift video on YouTube. All would have been either impossible or extremely expensive 25 years ago. All are free and available at any time—on a handheld device, on our desktops. Our words, ideas, emotions, and emoticons travel at the speed of light, from pretty much any point on the surface of the Earth to any other.

We may live in a mobile and wireless world, but wires still drive the global communications revolution. Your phone call, text, email, or emoji-laden tweet may travel wirelessly from your iPhone to the nearest cellular tower, but from there on out it is largely confined to cables, wires, and cords—express lanes coursing above ground, underground, and under the sea—especially if your message is going abroad. “More than 99 percent of signals of any sort that go between continents flow over undersea fiber-optic cables,” says Tim Stronge, research analyst at TeleGeography, a research and consulting firm. Were submarine cables not as pervasive, cheap, and functional as they are, most of us would still be living on data islands. To the extent that the world is now flat, it is largely due to the expansive network of undersea cables. They enable a dot-com entrepreneur in Perth, Australia, to collaborate with a programmer in Bangalore, India, serve a customer in Germany, and communicate with a supplier in China.

These contemporary Appian Ways are the vital back end of the Internet—and one of the wonders of the modern world. Lying under the murky depths of the Southern Atlantic, the placid, teal waters of the Caribbean, and the frigid, stormy Bering Sea, underwater cables withstand the ravages of sharks and resist immense pressure and the corroding influence of salt. Amid the sprawling network (laid out in this gorgeous map produced by TeleGeography), one stands out for its length. Starting in Australia and terminating in Germany, SEA-ME-WE 3 (for SouthEast Asia Middle East Western Europe) is a modern-day Orient Express. A marvel of modern synergy, it was built (and is still owned) by a consortium of 92 telecommunications firms. Running 39,000 kilometers—about 24,000 miles—and touching 39 landing points in 33 countries on four continents, SEA-ME-WE 3 is the closest thing we have to a transoceanic information superhighway.

Courtesy of JD Thomas/Flickr Creative Commons

Today’s submarine cables are the latest flowering of an infrastructure class that was pioneered in the 19th century, given impetus by a construction boom in the late 20th century, and which has been made immensely more powerful (and cheaper) by 21st-century technology developments. Indeed, thanks to the application of new hardware and processes, a cable like SEA-ME-WE 3 can now carry 40 times more data than it could when it was first laid—a feat that physical conduits for physical goods, like roads and railways, could never mimic.

The first great submarine communication cable, of course, was the telegraph line connecting England and the United States. In A Thread Across the Ocean: The Heroic Story of the Transatlantic Cable, John Steele Gordon describes how Cyrus Field rounded up cash and got the U.S. and U.K. governments to fund his scheme. (The Niagara, the largest ship in the U.S. Navy, laid out the cable.) The first message sent from Queen Victoria to President James Buchanan, in August 1858, inspired fireworks in New York City that set City Hall on fire. In a remark Tom Friedman might have appreciated, Cyrus Field’s brother, Henry, wrote that it “joins the sundered hemispheres. It unites distant nations, making them feel that they are members of one great family.” Three weeks later, the cable went dead. Tiffany & Co. bought parts of the unused cable and cut them into 4-inch pieces to sell. (One was auctioned on eBay last year.) Field finally succeeded in laying a lasting cable in 1866. The cost for capacity: $10 a word. By 1900, there were 15 competing threads across the ocean.

Laid in 1956, TAT-1, the first transatlantic telephone cable, used the same type of copper wire employed in terrestrial phone lines. But the midcentury threads were exceedingly narrow pipe. TAT-1 could accommodate just 48 64 kbps (kilobits per second) circuits—just four dozen phone conversations at once. It’s not surprising, then, that in the 1960s international phone calls cost about $3 per minute. The development of fiber-optic cable by Corning in the 1960s and 1970s (chronicled in a chapter in a book I wrote)—using glass as a transport medium rather than a metal—brought a quantum leap in the speed and capacity for communication wires. Fiber-optic cable—insanely thin glass threads, really—can handle so many more conversations and bits than wireless spectra can. The first fiber-optic cable laid across the Atlantic, the TAT-8, was completed in 1988 and could carry 7,560 simultaneous voice conversations.

The 1990s brought a boom in both the pace of construction and the power and capacity of cables. The AC-1 trans-Atlantic cable, an 8,700-mile round-trip line first used in 1998, could handle the equivalent of 483,840 simultaneous voice conversations, according to Stronge. Firms like Global Crossing, whose market capitalization peaked at $45 billion in the spring of 2000, laid pipe anywhere and everywhere—and then went bust.

SEA-ME-WE 3 began amid the tech bubble. Australia and the rest of Oceania are separated from other huge commercial and population centers by vast expanses of water. Australia’s line to the other six continents was an analog line, the AIS (Australia-Indonesia-Singapore) cable. Construction of SEA-ME-WE 3, which started in January 1997 and was completed in 2000, proceeded in a way that would have been recognizable to 19th-century telegraph cable experts. As Stronge notes, when cable is loaded onto a vessel, “They have this giant drum in the ship and hire people to walk the cable around in a concentric circle.”

The ships proceeded methodically, paying out cable that is the width of a garden hose—an outer diameter of 21 millimeters, to be precise—and encased in a plastic coating. From Perth, SEA-ME-WE 3 goes north. At Malaysia, a branch reaches out to East Asia, surfacing at Mersing, Indonesia; Danang Vietnam; and Shanghai. Across the northern stretches of the Indian Ocean it goes, hitting Sri Lanka, Mumbai, and Karachi, further west to Muscat and Djibouti City, before crooking up through the Red Sea and Suez Canal. From Alexandria, Egypt, it hits Mediterranean ports of call before wheeling around Iberia and France, finally ending in the chilly waters of the North Sea near Norden, Germany.

Technicians display the African Coast to Europe, or ACE, submarine fiber optic cable on the seashore of Libreville, Gabon, in 2011.

Photo by AFP/Getty Images

For most of its sojourn, SEA-ME-WE 3 lies on the bottom of the murky depths. In deep water—more than 3,000 meters—the cables are laid on the seabed. In shallower waters, where ships might snag them, a plow buries them. SEA-ME-WE 3 has two fiber pairs, and such cables often have copper running through them—which supplies the electricity that powers repeaters, small devices positioned every 50 kilometers that boost the signal. At certain points, the cable is up-armored—coated in metal tape, sheathing, or screens—to protect against potential dangers. (The extra screen helps shield electromagnetic waves that attract sharks.) While failures are often ascribed to monsters of the deep gnawing through them, Stronge says such instances are rare. “There was one famous incident in the 1980s when a cable failed, and they think it was because a shark had bitten through to where the electricity was flowing.” When links break or are severed, as has happened on SEA-ME-WE 3 on about a half-dozen occasions, ships are sent out to repair the damage. (Fishing nets and ship anchors account for most of these incidents.) The sea cables are connected to beach manholes at the shore, through which they connect to land cables and the broader terrestrial grids.

The global economy has benefited from the boom in cable construction. Immense excess capacity, combined with technological improvements, has led to falling prices. The stupidity of investors and the willingness of bondholders and stockholders to sacrifice their money so that others could have cheap communications infrastructure are dynamics we’ve seen in the telegraph and railroad industries. (I wrote a book about this, too.) “Prices for capacity are one one-thousandth what they were in the late 1990s,” Stronge says. Since 1997, the amount of “lit” capacity–i.e., the amount being used—in the Atlantic Ocean between the U.S. and Europe has risen from 33 gigabits per second to 27 terabits per second, an 818-fold increase. But, notes Stronge, the total capacity of all cables—including “dark fiber” that’s not in use—across the Atlantic is 173 terabits per second, which means just 16 percent is being used. On major submarine cable routes, bandwidth demand rose 4.5 times between 2009 to 2013. But even so, less than one-quarter of the potential capacity on these routes is being used. Every year, the price of connections grows cheaper. According to TeleGeography, median monthly lease prices on major submarine cable routes submarine cables fell between 10 and 26 percent in 2013.

Courtesy of TeleGeography. See a larger version or visit the interactive version of the 2014 Submarine Cable Map.

That’s in part because the state-owned and private telecom companies that have built and run the global network continue to add to it, especially in the Middle East, Asia, and Africa. (SEA-ME-WE 3 was followed by SEA-ME-WE 4, which provided redundancy along similar paths, from Singapore to France.) But it’s also because innovation on the back end has increased the carrying capacity of tubes that were laid down long ago. When SEA-ME-WE 3 was completed, it could carry up to 40 gigabits per second of data traffic. Today, SingTel, which runs the cable, says it has a capacity of 1 terabit per second—a 25-fold increase. That’s in large measure due to the introduction of wavelength division multiplexing. Essentially, a bunch of signals can now travel on the same pair of fiber cables because new, more powerful transceivers on the ends of cable lines can send and receive the signal on different frequencies of light. As SingTel notes, “The cable has been twice upgraded and it now consists of two fiber pairs, each carrying eight wavelengths.”

To the history-minded, the map of submarine cables is remarkably evocative. A host of them connects the Northeastern U.S. with England and France, mimicking the early patterns of North America settlement. Some follow the journeys of Vasco Da Gama and Magellan, bumping down from Portugal along the coast toward South Africa. There are tiny components like the Amerigo Vespucci, an 85-kilometer spur that connects Curacao, a former Dutch colony, to Bonaire, which is still part of the Netherlands. There are unlikely hubs, like Bude, at the tip of Cornwall in England, where seven cables arrive from across the seas. Like triremes, schooners, and clippers before them, these cables hug land and then seek direct, obstacle-free paths across the waters. But instead of delivering physical goods, they deliver digital goods and services.

Like all good networks, the mesh of submarine cables is being expanded to offer more capacity and more redundancy. The SEA-ME-WE 5, now under construction, parallels a good chunk of SEA-ME-WE 3 between Malaysia and France. And while it’s difficult to improve much on the speed of light, the network is getting marginally faster. It takes about 60 milliseconds to bounce a signal from New York to London. “But for some users of bandwidth, particularly banks that are doing trading or arbitrage, shaving off one millisecond can make huge profits,” Stronge says. That’s why Hibernia Networks is now working on Project Express, a cable that will carve a shorter path across the Atlantic—from Halifax in Nova Scotia to the west coast of England.

SEA-ME-WE 3 and its siblings may not be any more effective than the telegraph in joining sundered hemispheres or making distant nations feel like one great family. But they make it possible for us to lead 21st-century lives, at faster and faster speeds. And they should inspire the same type of awe that a 19th-century telegraph cable did. “These are the days of miracle and wonder,” Paul Simon once sang. “This is the long-distance call.”

Check back every week for a new modern wonder.

The International Space Station, shortly after undocking from the Space Shuttle Endeavour on June 15, 2002.

Courtesy of NASA/JSC

4 Our Readers’ Wonders

Any compilation that claims to be an authoritative ranking is bound to set off anyone who wasn’t included. So far, though, Slate’s efforts to name a new pantheon of seven brilliant, wonderful, largely hidden essential wonders of the modern world hasn’t inspired Vesuvian levels of outrage.

But as I learned as a young graduate student in history and repeatedly in the years since, dealing with ideas and narratives is as much an act of omission as it is an act of commission. So, before rolling out the final four wonders of this series (I already know what they are), I thought it would be smart to pause and make sure I’m not overlooking one that cries out for inclusion.

To that end, we combed the comments and put out a request to Slate’s Facebook followers, which received plenty of responses. The suggestions were typically intelligent, as I’ve come to expect from our readers.

So far, this series has been heavy on ingenious systems that involve the aggregation, organization, and movement of digital information. Some readers suggested a few more in that vein: the Internet itself, Google, Google’s search algorithms (which was on my original long list of potential wonders). Greg Packnett suggested Wikipedia: “A bunch of people got together in their spare time and decided to write down a quick summary of all the world’s knowledge, and it’s available through portable electronic devices.” Still others recommended the devices—smartphones—themselves.

Others suggested we lift our eyes to the heavens. “The International Space Station,” wroter Koh Jun Lin. “A multinational collaboration between sometimes bitter rivals, the longest continuous human habitat out of this world, a place to conduct research impossible elsewhere, and a source of inspiration.” Spoiler: Something interstellar might be coming in the next few weeks.

Plenty of commenters focused on what this series has left out. First: health care. One reader suggested we look into reliable birth control. Elizabeth Tobias pointed out that vaccines deserve consideration as modern wonders. “Listed as top medical achievement of the 20th century. This still qualifies as modern, even if you go back to Koch and Pasteur, etc.” While both birth control and vaccines fulfill some of the requirements for this series—feats of engineering, largely out of view, and taken for granted—they don’t quite qualify as 21st-century technological achievements. But what great leap in either of these areas have we seen in the past couple of decades that has transformed it into a brilliant system?

I had the same reaction to suggestions related to energy. “Alternating current transformers that allow electricity to be distributed safely,” suggested Russell Blank. “None of the three wonders of the modern world would be possible without AC power.” Another: “Green energy generation … solar arrays, wind farms, tidal generators.” The way in which electrons are produced, harnessed, stored, managed, and moved around the country—above ground, under ground—is indeed wonderful and evolving quickly. Perhaps an additional installment of this series is in order.

Some other suggestions, meanwhile, were easy to object to: streaming porn, movable type (it’s been around for nearly a thousand years), and, um, the battery-operated dildo.

There was one out-of-the-box suggestion, however, that struck a chord. The most impressive systems are those that convey physical goods. It’s one thing to move a bunch of digital files from one place to another without screwing things up. It’s quite another to move metal tubes filled with hundreds of people at extremely rapid speeds without doing so, which is one reason this series highlighted aviation control. A forthcoming installment will likewise focus on a miraculous conveyor of a life-giving substance that no human being can live without: water. But now I’m thinking we should swap that one out for another miraculous conveyor of a life-giving substance that few human beings can live without: “pizza delivered hot and fresh to your home in 30 minutes.”

Indeed.

Check back every week for a new modern wonder.

The seven wonders of classical antiquity were architectural marvels, triumphs of human ego and raw power. The great achievements of today, however, are made possible by systems, infrastructure, and technologies that are invisible. This series, which continued last week with the Earth’s amazing network of undersea cables, explores the wonders of our modern world. Here is the fourth wonder:

Animation by Lisa Larson-Walker. Photo by Thinkstock.

5 The New York City Water Supply System

When my Slate colleagues turn on the tap to fill up water bottles in their fourth-floor office in Lower Manhattan, they probably aren’t thinking about the liquid’s origin. They should. That water likely traveled more than 125 miles through one of the world’s most impressive conveying systems, one whose legacy goes back to the presidential administration of Martin Van Buren. With comparatively little power, those drops of moisture have been pushed from reservoirs sitting atop submerged villages in upstate New York; through some of the longest underground aqueducts in the United States, some wide enough to accommodate a school bus; through a brand-new filtration system; and then underground and into Manhattan via a sprawling grid of pipes. To a surprising degree, the whole process relies on natural forces—gravity, rain, the melting of snow—and old-school engineering, overlaid with some 21st-century improvements.

The pipes that carry this life-giving force are largely invisible to New York’s thirsty masses. (Here’s a great map.) The system includes 19 reservoirs nestled in the rolling hills and mountains, draining a sprawling 1.2 million-acre watershed; three controlled lakes; 300 miles of underground thruways, including one that burrows 1,100 feet underneath the Hudson River; and thousands of miles of thin pipe under New York’s streets. Together, they deliver fresh, potable water to 8.4 million people in New York City and another 1 million people upstate.

Much of New York City’s once-vaunted infrastructure is crumbling: the creaky George Washington Bridge, the leaky subway tunnels, the depressing midcentury mediocrity of LaGuardia Airport. But as old and in need of updating as it is, the water system is an unseen miracle, and one of the wonders of our time. “The design and engineering of New York City’s invisible water system—buried hundreds of feet below ground—is as brilliant as the engineering of the parts of the city the so impress residents and visitors above ground,” says Charles Fishman, author of the seminal Big Thirst: The Secret Life and Turbulent Future of Water. “Compared to many big U.S. cities, including Los Angeles and Atlanta, New York's water supply and water system are in generally great shape.” So ingenious is the system, Fishman adds, that New York’s water “doesn't need to be treated before arriving at faucets, and almost all the city’s water is delivered by gravity.” These two characteristics, combined with its sprawling size, make New York’s water system the greatest in the world.

The system emerged as a matter of necessity. “New York City developed this water system because it was unlucky,” says Kenneth T. Jackson, the Columbia University historian and authority on New York City. “It couldn’t could take water out of the rivers, because the Hudson is salty all the way up to Poughkeepsie.” In the 18th and early 19th centuries, the city’s growing number of residents relied on wells, water brought in on ships, and spring-fed ponds like the Collect (near what is now Foley Square), which quickly turned into dumping grounds for sewage and garbage. The fetid waters helped spawn the cholera epidemic of 1832, which killed more than 3,500 residents. And the absence of significant water sources in city streets thick with wooden buildings led to a series of disastrous fires. After the Great Fire of 1835, which consumed about 700 structures, municipal leaders were moved to act.

The new Croton Dam, the High Bridge, and distributing reservoir on Murray Hill (current site of the New York Public Library).

Images via Wikimedia Commons and Library of Congress

The city acquired water rights north of the city, dammed the Croton River, and then funneled the waters that would pool behind it some 41 miles to the middle of Manhattan via the Croton Aqueduct. Built of iron pipes and surrounded by brick masonry, the Croton Aqueduct made a majestic entrance into the city via the High Bridge, the first bridge connecting the Bronx to Manhattan. The water was funneled into a holding reservoir in what would become Central Park, and then to the distributing reservoir—a castle, really—at the junction of 42nd Street and 5th Avenue, where the New York Public Library now stands. Completed in 1842 at a cost of $11.5 million, the system was “one of the great engineering achievements of the nineteenth century,” trumpets the Encyclopedia of New York City.

So-called wonders of the world tend to crumble or recede into obscurity. And some of the most prominent components of the Croton system are now relics. The High Bridge is being converted into a pedestrian walkway, while the big reservoir at 42nd Street was dismantled in the 1890s. But the Croton system had two design components that were mimicked as the system expanded, ensuring its continued grandeur. Bringing water from distant mountains meant it would be clean and wouldn’t have to be treated heavily—so long as the transport system kept pollutants out. Second, and just as important, water traveled from higher elevations to sea level. And that meant gravity would do the heavy lifting of moving the water, while the pressure that built up in the system would force it up to the surface and through hoses. “This got New York away from the bucket brigade, and provided the basis of modern firefighting,” says Adam Bosch, a spokesman for the New York City Department of Environmental Protection, which runs the system.

Built at a time when the city’s population stood at about 200,000, the Croton system served well until the early 1900s. By then, New York’s population soared to more than 3 million, thanks to immigration, expansion, and the annexation of the Bronx and Brooklyn. In the early 20th century, the city expanded the system to develop new resources in the Catskills. The Ashokan Reservoir, whose creation required the submerging of seven villages, came into service in 1915. A system of pipes and canals were constructed to ferry water via the Catskill Aqueduct 92 miles to the Kensico and Hillview Reservoirs in Westchester—including a circular tunnel with a diameter of 14 feet that goes 1,100 feet under the Hudson River near West Point. Water Tunnels No. 1 (completed in 1917) and No. 2 (completed in 1937) carried the water from Yonkers into Manhattan. Next came the Delaware system to the city’s northwest. Starting in the 1950s, vast pools of water created by damming tributaries of the Delaware River were fed into new infrastructure, including the Delaware Aqueduct, which at 82 miles is the longest continuous underground water tunnel in the world. Here, again, gravity does the work. The highest reservoirs are about 1,200 feet above sea level. And the volume of water pushing down through the pipes creates an enormous amount of power. Today, Bosch notes, “the pressure is so great that it can take it to the sixth floor of most boroughs without any pumping,” said Bosch.

Five men standing at the point where the three underground passages of New York's Catskill Aqueduct meet.

Photo by Hulton Archive/Getty Images

The 500 miles of fat pipes upstate are augmented by 6,500 miles of narrower underground conduits that run underneath the five boroughs, from the crags of Riverdale to the distant, wave-tossed shores of the Rockaways. From the Hillview Reservoir in Yonkers, right on the Bronx border, pipes plunge a few hundred feet into one of the three massive water tunnels that carry water to the south about 500 feet below ground level. Every 20 blocks or so, vertical tunnels sprout up to feed into trunk water mains, with a diameter of about a foot. Ultimately, they connect to buildings, whose pipes are private property.

As is the case with the submarine cables I discussed in the last installment of this series, redundancy is key to the system functioning at a high level. The new is continually built to augment the old. Water Tunnel No. 1 has been running continuously since 1917. Work on Water Tunnel No. 3, the latest of the system’s grand travaux, has been underway for more than 40 years. Like the electrical system, it’s a buried, interconnected grid. That means when a break occurs, it can be isolated, with the water rerouted around the affected area.

In New York, infrastructure tends to cost more because people are paying for the convenience, the reliability, and the extra degree of difficulty inherent to building here. But New York’s water prices are actually pretty reasonable. This comparison from 2010, when the uniform rate was $261 per 100 cubic feet, places New York 15th lowest out of 24 large U.S. cities. The DEP says the typical single-family homeowner pays about $1,024 per year for water and sewer bills—which comes out to about a penny per gallon.

Water sampling station, East Village.

Photo by Mike Licht/Flickr Creative Commons

As with every wonder in this series, part of what drives the New York City water system is its back end. About 1,000 of DEP’s employees work upstate in the watershed and infrastructure, and another 1,200 toil on the in-city system. Constant vigilance is required. Scientists upstate continually monitor water quality in the reservoirs and release water only from the depths with the highest quality. The aptly named Operations Support Tool is a computer model that integrates a range of human and digital information to make sure water levels throughout the system are adequate. Stream gauges placed throughout the watershed transmit data on water levels. Snow pillows—sensors that can detect the amount of water embedded in snow as it accumulates—are sprinkled throughout the region. And DEP has developed a hydrologic forecasting service in conjunction with the National Weather Service.

Reducing consumption has also been a vital means of keeping the system healthy. In 1980, New York City’s population of 7.1 million people consumed about 1.5 billion gallons per day. By contrast, today, average daily consumption for Gotham’s 8.4 million people has fallen to about 1 billion gallons per day. That represents an absolute decline of one-third, and a decline of per capita daily consumption of 43 percent. The decline of manufacturing and heavy industry in the region accounts for some of this drop. But low-flow shower heads and toilets and widespread conservation efforts have helped. Things that are measured precisely are, it turns out, more likely to be controlled.

DEP once kept track of customer usage by sending employees to read meters once per month. (They would estimate usage if they couldn’t get access to the property.) These days, DEP’s 834,000 customers have wireless meter-reading devices, which update the agency every couple of hours on usage. The information is shared in real time with customers, so they can manage their use and make sure their own internal water systems are functioning properly. The new system has cut into billing disputes and catches leaks or problems that may have otherwise gone undetected for weeks. Some 209,000 customers have signed up to receive notifications of leaks, which are often flagged when the system notices unusual or excessive use at a particular address.

None of this is to say the system is perfect. “New York does suffer the same neglect and complacence as other cities,” says Fishman. Two of the three giant tunnels that bring the water are 97 and 79 years old, respectively, and it’s not uncommon for mains to burst. But DEP continues to manage the type of infrastructure projects that would have made Robert Moses, New York’s mid-20th century emperor of infrastructure, proud. The agency has spent $20 billion over the past decade to upgrade pipes, and it plans to spend another $14 billion over the next decade—largely on things that the public will never see. Work on the massive Water Tunnel No. 3 continues as it extends to Lower Manhattan and to Queens. In 2012, a large disinfecting plant came on line in Valhalla, in Westchester County. There, water is exposed to 11,760 ultraviolet light bulbs, which sterilize microorganisms that can cause gastrointestinal illness. With a capacity of 2.02 billion gallons per day, it is five times bigger than America’s next largest such plant in Los Angeles.

And in the cold rock deep underground, engineers are toiling to fix a pretty big flaw in the system. The New York Times reported last week on the ongoing efforts to fix a leak in the Delaware Aqueduct, which lets 35 million gallons of water go to waste each day. Essentially, they are building a 2-mile bypass tunnel, with a diameter of about 13 foot, around the troubled section. The aqueduct bypass is likely to cost $1 billion.

New York City’s water—soft, surprisingly pure, and endowed with the properties that make the city’s bagels and pizza dough world-beaters—may be cheap for its users. But keeping it cheap is an expensive, and amazing, proposition. The movement of a colorless liquid underground may inspire neither poetry nor particularly soaring prose. That doesn’t make the accomplishments of this system any less meaningful. “High and fine literature is wine, and mine is only water,” Mark Twain wrote “But everybody likes water.”

Check back every week for a new modern wonder.

The seven wonders of classical antiquity were architectural marvels, triumphs of human ego and raw power. The great achievements of today, however, are made possible by systems, infrastructure, and technologies that are invisible. This series, which continued last week with New York City's unparalleled water system, explores the wonders of our modern world. Here is the fifth wonder:

6 The Collaborative Weather Forecast

It’s a Sunday in late fall. I’m about to head out for a two-hour bicycle ride, which will take me from the coast of Long Island Sound to the hills of Fairfield County, Connecticut—30 miles through six different towns and several different climates. Having a detailed understanding of weather conditions and how they might change is vital. Riding up certain hills into headwinds would be demoralizing. The inland tends to be colder, which might dictate how many layers I wear. And my pathological desire to avoid rain might mean cutting the ride short. So before I head out, I open up WunderStation, the app produced by Weather Underground, the first online weather service. I tap into a network of stations scattered around the region. A few blocks away, it’s dead calm and in the mid-40s. Up north, it’s already several degrees colder, and winds of 12 miles per hour are kicking up from the west. There’s a 60 percent chance of rain at 2 p.m. I strap myself in and head out—and the weather I find essentially matches what I just saw on my iPad.

For most of history, forecasting the weather has meant making educated guesses—the ancients read the clouds and kept track of events from the previous year. Slowly, technology came into play. “The rain gauge, barometer, anemometer, hygrometer and thermometer were all invented in the years between 1400 and 1700,” as the National Oceanic and Atmospheric Administration notes in its history section. These were all more or less reliable methods of monitoring current conditions. The Old Farmer’s Almanac, America’s oldest periodical (founded in 1792), provided data, like sunrise times and tide charts, to people who made their living on the land and sea. But editor Thomas Roberts also made long-range weather forecasts, based on a secret formula “kept safely tucked away in a black tin box at the Almanac offices in Dublin, New Hampshire.”

When the telegraph enabled instant communication, it became possible to produce crude weather maps, and the National Weather Service was founded in 1870. “Later that year, the first systematized, synchronous weather observations ever taken in the U.S. were made by ‘observing-sergeants’ of the Army Signal Service at 22 stations and telegraphed to Washington,” according to the NWS. Next, NWS number-crunchers began to turn that more accurate set of observations into predictions. The NWS began issuing three-day forecasts in 1901. (In 1902, no doubt, Americans first began to carp about the inaccuracy of these predictions.)

Weather forecasting, then and now. Left, the meteorological work of the United States Signal Service, interior of the “Fact Room,” where the weather probabilities were created, in Washington, D.C., 1881. Right, meteorologist Jim Fracasso monitors weather in NOAA’s Center for Weather and Climate Prediction on July 2, 2013, in Riverdale, Maryland.

Left: Illustration courtesy Library of Congress. Right: Photo by Mark Wilson/Getty Images.

In the 20th century, communication technologies (telephone, radio, television) and new observation and location technologies (airplanes, sonar, radar, satellites) vastly increased our ability to capture and distribute weather-related information. NWS began issuing 30-day weather outlooks in 1950. Today, the NWS has some 5,000 employees in 122 weather forecast offices. While it uses digital technology, NWS is quite analog—it gathers information at several fixed spots, relies on a bunch of scattered data points to produce a picture and a forecast, and disseminates it by pushing it through different media (such as broadcasts and warnings). And its products can be maddeningly inaccurate at times.

Our mobile, wireless world makes possible a much more interactive, accurate, and detailed weather forecasting system—one that packs more data, for free, onto the desktop of a casual user than the most seasoned professional forecaster would have been able to see a decade ago. Many of the marvels I’ve highlighted in this series take an existing system and then layer new technologies, smart number-crunching, and innovative models on top of them to make them more robust, more user-friendly, and more valuable. The same is true with the many apps and websites that specialize in weather, including Dark Sky, Yahoo Weather, and Perfect Weather. Among these, Weather Underground stands out, in part because it was the first online weather service, and in part because it demonstrates that a self-described “community backed by science” can provide significantly more accurate data. The more precise and data-rich this system of apps, satellites, meteorologists, and enthusiasts gets, the more it feels like a modern wonder.

Weather Underground was founded in 1995—still the dawn of the Internet—by a group of academics at the University of Michigan. “The sole purpose was: Let’s collect a bunch of weather data and get it out to people through a website,” says Jim Menard, senior vice president and general manager of Weather Underground. It’s somewhat ironic: Weather Underground harkens back to the anti-establishment movement of the 1960s, a radical group aimed at blowing things up and subverting the government. In a sign of how times are changing, this Weather Underground is working on improving the information provided by the government and is very much part of the establishment. In 2012, it was acquired by the Weather Company, which also owns the Weather Channel.

An Automated Surface Observing System installation.

Photo courtesy NWS Collection/NOAA

A great deal of weather information was—and is—already available to the public. The whole point of the NWS was to gather data from its observation network and plug it into models that could provide forecasts and then alert the public in case of danger. NWS relies on some 2,000 Automated Surface Observing System units, located mainly at airports throughout the country, as well as another 26,000 stations scattered around the world that part of the Meteorological Assimilation Data Ingest System.

That may sound like a lot. But it doesn’t result in anything like blanket coverage. And Weather Underground realized it could improve this system by turning weather into a crowdsourced big-data affair. Boosting the number of physical observations would provide more detailed local weather (like zooming in on Google Earth), and that data would in turn lead to the construction of more effective forecasting models.

In essence, Weather Underground borrowed a page from the hyperlocal all-news cable channels that only cover a particular city—as NY1’s tagline put it, “As local as local news gets.” So it starts with the data that NWS collects and disseminates. Then it enlists the public by encouraging hobbyists to link their personal weather stations to its system. “Instead of relying on the observation point that is at the airport, we let people put a weather station in their backyard and make it easy for them to submit that data to us,” Menard says.

Personal weather stations are electronic devices that measure items like temperature, relative humidity, wind speed, and rainfall. As with so many digital and wireless technology products, they’ve gotten much cheaper in recent years. “Ten years ago, if you could get one for $1,000, you’d be doing well, and they could go upward of $10,000,” Menard says. In recent years, they’ve become cheaper and can be more easily wired to the Internet. “There are a number of vendors that, for $150 to $200, provide a weather station that is pretty good,” Menard says. Weather Underground’s site recommends high-end ones like the RainWise PWS, for about $1,000, as well as the $179 Netatmo.

Weather Underground’s personal weather station network, launched in 2001, grew slowly, but has recently caught fire. This year alone, its network has grown from 30,000 systems to about 55,000. Every 10 minutes or so, each PWS reports its latest data. (More sophisticated ones upload every few seconds.) The thousands of systems—unobtrusively attached to homes, offices, stores, and poles—form a highly active network of silent and invisible correspondents. In a 3-mile radius of my home in Connecticut, there are nine stations. And in areas where the climate can change dramatically in a short distance, this type of density makes a big difference in painting an accurate picture—I count at least 50 in San Francisco proper.

Users can access the system to find out hyperlocal weather information. But Weather Underground uses this data to feed its proprietary modeling systems. “What you’re getting is a forecast for that exact latitude and longitude,” says Menard. As this description shows, compared with those of the NWS, Weather Underground’s forecasts update more frequently, include more parameters, and extend further into the future.

Weather Underground’s crowdsourcing goes beyond the network of passive weather broadcasters. As Waze does with motorists, Weather Underground’s mobile apps allow people to report conditions—what you see, estimated cloud cover, hazards like slippery or unplowed roads. The reports last for 15 minutes, and other users are invited to affirm or reject condition reports. In November, Menard tells me, more than 1 million people submitted such updates.

Like all Weather Underground updates, this data is funneled into its proprietary models and forecast engines. To a degree, Weather Underground is the hipper, nerdier, younger sibling of the more basic, hype-prone Weather Channel. “The users of Weather Underground are people that are extremely interested, they want to go deeper,” says Menard. Like many of today’s hottest technology companies, it is focused on building a community—Weather Underground is a place where obsessives link up with other obsessives, where they gain prestige by sharing information, and where users swap photos as well as data. “We have a large community that is interested in the science of weather, in particular global warming and following from a scientific point of view why a certain storm was so bad,” Menard says.

The sun sets behind oak trees after a storm in Los Angeles on Dec. 12, 2014. The storm pounded Southern California with heavy rain and high winds, triggering flash floods and mudslides that prompted the evacuation of hundreds of homes, damaged dozens of others, and disrupted passenger rail service along the coast.

Photo by Lucy Nicholson/Reuters

As with many new technologies, using Weather Underground feels cool and awesome, but also slightly Orwellian. It works best only if you’re willing to share lots of information gathered at your own expense and if you’re willing to let a faceless entity know precisely where you are at all times.

The marriage of greater data, more sophisticated number-crunching, and personal observation has certainly made the weather map more rich and detailed. But does it make long-term forecasting more accurate? Anyone who’s ever looked at a five-day forecast—and freaked out at the prospect of a rained-out vacation only to find sunny skies upon arrival, or vice versa—knows that there is a great deal of false precision to these forecasts. And this is one of the areas in which technology doesn’t overcome nature. Menard argues that things have gotten better. The “skill scores”—a measure of forecast accuracy—on a five-day forecast 10 years ago are about what professionals can get on a six-day forecast today. “Your seven-day forecast is pretty accurate, and you could not have said that 10 years ago.” But beyond that, the weather is changeable, and truly long-term forecasts are essentially worthless. “There’s a natural amount of chaos in the atmosphere,” Menard says.

Even so, it’s quite remarkable how much we can learn about atmospheric conditions through an app—which is constantly sucking up data from tens of thousands of observation points and presenting them in a free, easy-to-use interface—all without turning on the television or radio. In the 21st century, you don’t need a weatherman to know which way the wind blows.

Check back every week for a new modern wonder.

The seven wonders of classical antiquity were architectural marvels, triumphs of human ego and raw power. The great achievements of today, however, are made possible by systems, infrastructure, and technologies that are invisible. This series, which continued last week with collaborative weather forecasting, explores the wonders of our modern world. Here is the sixth wonder:

Photo illustration by Slate. Photo by Noor Khamis/Reuters.

7 The Mobile Wallet

Cash is king, the saying goes. But it’s actually something of a curse in many parts of the world. A horribly inefficient and often dangerous means of storing value and exchange, coins and bills can easily be stolen, or lost, or destroyed in a fire. “Cash is the most formidable enemy of the poor,” Tonny K. Omwansa and Nicholas P. Sullivan write in their 2012 e-book Money, Real Quick, which chronicles the heartening rise of M-Pesa, a new system that’s bringing secure payments and money storage to millions of new consumers.

For the world’s wealthy, cash has long been free from its metal and paper incarnations. The global network of banks and payment processors is wired to zap cash electronically around the world. But Visa, MasterCard, and global banks like HSBC and JPMorgan Chase are expensive wired systems that are actually quite sluggish. While you can conduct your transactions wirelessly, money still moves through a complex network of brick-and-mortar banks and hard-wired terminals. And that can’t possibly accommodate the needs of most of humanity.

In the U.S., innovative services like Google Wallet, Square, and retailers’ payment apps—all of which basically sync prepaid cards or debit cards to mobile devices—haven’t made much headway. “After years of effort, just $3.1 billion in purchases came from mobile wallets last year, according to Javelin Strategy,” as Fortune noted earlier this year. Research firm eMarketer reported that “proximity payment transaction values”—commerce done by reading a smartphone, for example—totaled an estimated $1.6 billion in 2013. Venmo, an app that allows people to send cash to one another instantly, is gaining some traction.

Square, Google Wallet, Venmo.

Photos by Shardayyy/Flickr Creative Commons, Google, and Venmo

But it’s small change. Along with broadband speed, mobile payments are another technology area in which the U.S. lags badly behind global standards. Only this time, we don’t trail the advanced economies of Scandinavia. Rather, the standard for simplicity and efficacy is being set in an impoverished country: Kenya. The mobile phone company Safaricom introduced M-Pesa in the fertile and remote Great Rift Valley seven years ago. The all-wireless system, which allows people to send and receive cash with the same reliability, ease, and low cost as they can send SMS texts, has grown quickly from startup to national standard. Vodafone, the telecommunications giant that owns 40 percent of Safaricom, estimates that M-Pesa has some 18 million customers, most of them in Kenya. In a typical year, transactions worth about 20 percent of Kenya’s GDP are processed by the system. In the U.S., that would be equal to more than $3 trillion. In recent years, a great deal of financial innovation—structured mortgages, tax-avoidance strategies—have generally benefited the already comfortable. M-Pesa and its growing number of peers in the developing world stand out, however, for their ability to provide a remarkably valuable service to consumers whose needs have long been ignored. They don’t simply liberate money from its physical manifestation; they’ve shown the potential to liberate people from some of the shackles of poverty. And that’s what makes these mobile payment systems a wonder of the modern world.

Customers queue for mobile money transfers, known as M-Pesa, inside a Safaricom office in Nairobi, Kenya, on July 15, 2013.

Photo by Thomas Mukoya/Reuters

M-Pesa and its imitators have thrived in part by freeing exchange from the expensive, inaccessible physical networks and infrastructure that have heretofore confined money. (Other services include Telenor’s Easypaisa in Pakistan, Smart Money in the Philippines, and True Move in Thailand.) “There’s been no innovation in paper notes and cash for 2,600 years,” says Tim Harrabin, senior adviser to Analysys Mason and an expert on mobile payments. “The mobile payment system is about replacing notes and coins and enabling people to move money.” Instead of replicating the developed world’s financial system, M-Pesa leapfrogs it. And it does so by marrying Kenya’s abundant human capital to systems that have proven to thrive in the harsh environment of sub-Saharan networks.

Banks, which have been around for many centuries, represent one of the most obvious examples of the failure of trickle-down economics. They were founded to serve the rich. And today, about 2.5 billion adults—half of those on the planet—are estimated to be unbanked. In Kenya in 2006, fewer than 20 percent of the people had bank accounts. “In 115 years, banks provided their customers with 43 licensed commercial banks, 1,045 bank branches, and 1,500 ATMs,” write Omwansa and Sullivan. This, in a country with a population of 40 million. Only about 100,000 people had credit or debit cards. “If you look at the emerging market, there’s a huge lack of infrastructure. There are no banks, there are no bank branches. There are no real financial services in the rural areas,” Michael Joseph, the South Africa–born former CEO of Safaricom who helped create M-Pesa, tells me. “But the needs for the things that banks provide—safe place to store money, someone to process transactions—were certainly there.”

In contrast to banking, mobile telephony has diffused rapidly from a plaything of the elites to a mainstay of the masses. According to the International Telecommunication Union, this year there were to be nearly 7 billion wireless phones in the world, “corresponding to a penetration rate of 96 percent.” In Africa, some 60 percent of people have mobile phones.

A man works in his cellphone repair shop near a busy street market on Nov. 18, 2007, in Ghana.

Photo by Shaul Schwarz/Getty Images

This gaping chasm between the number of people with phones and those with bank accounts provided an opening, but not for a bank. Safaricom dominated Kenya’s mobile market. As part of an effort to keep subscribers from switching, it decided to offer a new service that would allow people to send and receive money through their phones.

Safaricom modeled M-Pesa in part on the ancient system of Hawalah, in which trusted intermediaries function as money transfer agents. “It replicates exactly what Hawalah does, but it’s more formalized,” says Joseph, who is now director of mobile money at Vodafone.

Here’s how it works. A mobile phone subscriber registers with a local agent—often the same person who sells airtime or SIM cards—by showing her national identification card. She gives money to the agent, who transforms the cash into electronic money via a series of SMS texts. The agent puts the cash in her account, which is in turn held in a centralized bank account. Once the cash is loaded, the customer can use her phone like a debit card (paying people via SMS), or like a card reader (receiving payments via SMS), or like an ATM card (turning electronic money into cash at outposts run by agents)—but without the high fees typically inherent in those transactions. (There’s no charge for uploading money, but there is one of about 1 percent for getting cash.)

In a country where a bank branch could be a day’s walk away, where sending a remittance might mean giving cash to a bus driver and hoping he delivers it, M-Pesa was something like a godsend. When the mobile payment system launched in March 2007, Joseph says the company expected to enroll a few hundred thousand people in its first year. After 12 months, 2 million people had signed up. The company expanded the service to Tanzania, Mozambique, and India, and it continued to attract users in Kenya. Now M-Pesa says it has about 17 million customers who move about $1.5 billion through the system each month—a remarkable level of penetration.

What makes it work? M-Pesa’s genius is in the simplicity of the design the business model, and the ability to avoid the heavy and expensive infrastructure associated with other payments systems. Customers have two PINs—one for their phones, one for M-Pesa. Each transaction is conducted via an encrypted SMS that runs through M-Pesa’s mobile money platform. Users receive confirmations by text and can get their balance and transaction histories.

A true mobile payment system like M-Pesa offers several advantages over debit card systems. Mobile phone operators in emerging markets already have a network of low-cost distribution points where people can gain access to cash—the agents who sell airtime and SIM cards. M-Pesa has recruited 160,000 agents in Kenya. So even in rural areas, people are never too far from access to the service. The screen of a phone is much more information-rich than, say, a debit card. Unlike debit cards, M-Pesa lets people send money directly to other people. And it can be used by people who don’t need equipment or infrastructure other than their mobile phones.

M-Pesa in Iringa, Tanzania.

Photo by Brian Harries/Flickr Creative Commons

M-Pesa is much faster, too. Unlike credit and debit card systems, which may take a few days to settle transactions, M-Pesa moves money instantaneously. Visa and other electronic payments systems we use are much more complicated: They must be processed by hard-wired terminals and involve cardholders, merchants, issuing banks, and processors, not to mention the transaction fees that can often amount to 2 or 3 percent of every transaction. M-Pesa is also quite safe. “We’ve been operating seven years, and have had many millions of transactions,” says Joseph. “To date, we have not had any hacking or anything like that.”

M-Pesa originally targeted Nairobi’s higher-income men, who would use the system to send money to relatives in villages. But urban shopkeepers and rural farmers have picked up on it. Originally designed as a peer-to-peer network, M-Pesa has evolved into a commercial tool. Coca-Cola’s Kenya distributor uses M-Pesa to accept payments from its network of vendors. Well-off people use M-Pesa to pay their domestic staff. As Omwansa and Sullivan note in Money, Real Quick, the Mumias Sugar Company uses M-Pesa to pay many of its cane cutters instantly. (Previously, they’d have to line up for hours to get paid and miss work as a result.) The company has also done deals with banks that allow people to set up savings accounts through M-Pesa and save in increments of as little as a few pennies.

A man sends money through M-Pesa in Nairobi in 2007.

Photo by Tony Karumba/AFP/Getty Images

In countries where a great deal of economic activity takes place in the shadows, M-Pesa and its rivals have had the effect of bringing more economic activity on the books. Money simply moves more quickly and efficiently throughout the economy when it travels via SMS. While traditional banking dwarfs this sector, the potential is immense. And that’s in large measure because payment innovations are simultaneously benefiting the wealthy, who move cash in big chunks through services like bitcoin or Apple Pay, and the massive numbers of poor people, who move cash in small increments.

Currency systems are circles of trust. So as these mobile payment systems trickle down and rise up, they’re likely to gain more momentum, abetted not just by those without access to traditional banks but by the those who are looking for excuses to avoid them following the financial crisis. Just as the exchange of digital information has boosted productivity and growth sharply, so, too, can the exchange of digital money. Imagine if India were able to deliver social-welfare benefits through digital cash and not through agents who might pilfer the aid. Imagine how much more effective tax collection would be in Italy and Greece if traceable mobile payments replaced cash. Imagine how crime might fall around the world if people in dangerous neighborhoods stopped stuffing money under their mattresses. Imagine how migrant workers would increase their effective wages simply by sending money home via text rather than through expensive money transfer services.

Too frequently, digital technology has been a force for the expansion of global income inequality. By enabling cheap phones to send small bits of cash at very cheap rates, mobile payment systems won’t take anything away from the haves. But they may give something quite valuable to the have-nots.

Check back next week for our final modern wonder.

The seven wonders of classical antiquity were architectural marvels, triumphs of human ego and raw power. The great achievements of today, however, are made possible by systems, infrastructure, and technologies that are invisible. This series, which continued last week with low-infrastructure mobile wallets, explores the wonders of our modern world. Here is the final wonder:

The KAT-7 Array radio telescope dish points skyward at the proposed site for the Square Kilometre Array telescope near Carnarvon, South Africa, on May 18, 2012.

Photo by Mike Hutchings/Reuters

8 The Orbiting Communications Grid

You’re trekking on the steppes of Outer Mongolia. And you’ve forgotten the birthday of your partner, who happens to be hiking in Patagonia. And you need to check in with a colleague who’s on a cruise in Alaska. Then you remember that you need to order some flowers for your mother, who lives in Florida and whose birthday is next week. It’s simple, really. Whip out a phone, move a few feet away from your yurt so you have a clear shot at the skies, and dial. If you’re a customer of the satellite phone company Iridium, you can connect with anybody, anywhere on the planet, in just a few seconds.

Fine, so that’s a pretty unlikely scenario. But as a feat of technological derring-do, it requires a system that we’ve all come to rely on to different degrees—to receive HBO signals, to view footage on the news, to listen to the radio. These signals can travel from one point on the globe to another in part by soaring up into the heavens to satellites that collect, amplify, and redirect the data to receivers embedded in myriad devices back on Earth.

Iridium, which notes it “is the only satellite communications company that offers truly global voice and data communications coverage,” employs a network of 66 satellites that spin around the Earth a few hundred miles up. The company had an inauspicious start—it went bankrupt in 1999 soon after going public—and it’s still relatively small. Revenues last quarter were about $100 million, and it has about 705,000 subscribers. Like others in the high-end communications business, it has a symbiotic relationship with the defense establishment. But no company better represents the potential and awesome power of the subject I’ve chosen for the final installment of this series on our invisible modern wonders: communications satellites.

The number of objects in Earth orbit has increased steadily, by 200 per year on average. The objects here are an artist’s impression based on actual density data but are shown at an exaggerated size to make them visible at this scale.

Image courtesy European Space Agency via NASA

Why would a series on life in the current century end with a technology that helped define the second half of the previous one? When I started this series, my aim was to redirect the sense of awe that once accompanied gazing up at the Great Pyramid or the Brooklyn Bridge toward the hidden systems that make our world work. I set out to find networks that are as remarkable for their ingenuity as for their reliability—things that simply work, day after day, despite physical challenges and occasional glitches. Thus far, I’ve looked at systems that convey massive physical objects (like airplanes) and life-giving natural elements (like water) and vital information (like Internet traffic and weather and road data).

The common thread running through them is a kind of elegant, effortless mobility. And it struck me that no system offers the ability to deliver its chosen product or service from any point on Earth to any point on Earth as incredibly as satellites do. For all of our wireless capabilities, to a very large degree we still rely on wires to communicate, as I noted earlier in this series. Only satellites can truly move signals (and the products and services they contain) from anywhere to anywhere—to emerging markets, to the deserts and mountains, to ships at sea, or to cars stuck in traffic on I-95—with a great deal of precision. If this orbiting latticework, which potentially connects every corner of the globe, can’t be called a modern wonder, what could be?

Pretty much every item launched into space in the first half of the 20th century fell back to Earth after it ran out of fuel or momentum. None managed to travel far enough to gain the magic balance between momentum and gravity that would keep it in orbit. Then, on Oct. 4, 1957, the Soviet Union launched Sputnik and helped ignite the space race. A few months later, the U.S. managed to launch its first satellite, the 30-pound Explorer 1 (thanks in part to the expertise of German rocket scientist Wernher von Braun).

The original U.S. satellites were designed primarily to gather information and to transmit it back to Earth. Explorer 1 detected cosmic rays, for example, before stopping its transmissions in 1958. It would fall back to Earth in 1970.

Technicians work on Telstar, the first TV satellite, before its launch by Thor Delta rocket on July 10, 1962.

Photo by Keystone-France via Getty Images

That was an impressive achievement. But satellites would truly become indispensable only when they developed the ability to receive data from Earth and then to beam it back with great efficiency—to become, as the Satellite Industry Association calls them, “cell towers in the sky.” That came in 1962, with the launch of Telstar 1, which the Canadian-based satellite company Telesat describes as “the world’s first active communications satellite.” Ranging around in low orbit—between 300 and 500 miles above the Earth for seven months, “its technology of receiving radio signals from the ground, and then amplifying and retransmitting them over a large portion of the earth’s surface, set the standard for all communications satellites that followed.”

In many ways, Telstar 1 and its successors provided the template for our mobile and digital world—vastly expanding the range of communications and what could be communicated and delivered, from where, and to where. Over the coming decades, more satellites went up, generally backed by consortia of government agencies and telecommunications companies. And they grew more sophisticated. Satellites launched into geosynchronous orbit—more than 22,000 miles above the Earth—could cover a great deal of territory as they tracked the planet’s rotation. A system of three satellites in geosynchronous orbit can cover the world, whereas several dozen satellites in low Earth orbit would be required to do the same.

The first users were telephone companies, who used satellite as an alternative to long-distance wires. Then, in the 1970s, HBO used a satellite to beam movies directly to subscribers’ homes. News and sports companies used satellites to provide live coverage. “By the 1990s, satellite communications would be the primary means of distributing TV programs around the world,” as Telesat notes.

Of course, these efforts consisted mostly of delivering signals from a stationary point (a television truck, an HBO transmission center) through satellites to other stationary points back on Earth. The big commercial leap for satellites has come in the last 15 years, now that those recipients are increasingly mobile. Iridium helped lead the way with mobile phones. After it went bankrupt—as many pioneering telecommunication firms have done, dating back to the telegraph—Iridium was taken for pennies on the dollar and continued to operate. (The technological model, it turned out, worked better than the initial financial model.) Iridium developed a smart network—satellites that could receive signals from mobile phones anywhere on Earth, share data with one another, and then reach out to another moving target anywhere on Earth. As Air and Space magazine notes, “That capability makes the system the only one in the world that can connect absolutely anywhere to absolutely anywhere else.”

Now Iridium is part of what has become a very large industry of satellite manufacturers, launchers, and operators. The sector had revenues of $189.5 billion in 2012, according to a 2013 report published by the Satellite Industry of America. More than 1,000 satellites are in the sky, owned and operated by major networks like Intelsat, Entelsat, and XTAR. About half are in low Earth orbit, and about 40 percent are in geosynchronous orbit, with a much smaller number of satellites in elliptical orbit or medium Earth orbit.

It’s hard to grok how much the satellite industry influences your life until you take an inventory of the industries and services it enables. This hit me recently as I walked along the rooftops of Jerusalem’s Old City and noticed that virtually every roof—in virtually every quarter—had a satellite dish for telephone, Internet, or television service. Yes, television signals make it possible for people in Israel to watch live feeds of sporting events and awards ceremonies. But they also let restaurants in Buenos Aires accept payments on debit cards belonging to tourists from Madrid, and allow international relief agencies to coordinate the response to Ebola, or let Sirius radio subscribers play E Street Radio as they tool around rural Vermont.

Satellite dishes dot the rooftops of buildings in Cairo on Jan. 9, 2014.

Photo by Khaled Desouki/AFP/Getty Images

Impressively, satellites manage the difficult trick of being both in the wholesale and retail businesses, something that sets them apart from other technologies. Acting as a wholesaler, satellites connect networks to one another, enabling the massive, commoditized exchange of data among networks, among companies, and among collaborators. Yet at the same time, satellites can solve the vexing problem of the last line—how to get a product, service, or information from the main trunk line to the millions of points, many of them isolated and distant, for cheap.

Yes, the Internet and wireless communications have been a huge boon to businesses and individuals alike. But I’d argue that the pervasive system of satellites, silently speeding through dark, empty space, is what truly epitomizes our anytime, anywhere, 24/7, all-you-can-eat data mentality. And, perhaps more so than any other network, these satellites are invisible to the human eye—the overwhelming majority of us will pass our days on Earth without ever spotting one. They are omnipresent, yet completely unobtrusive. If you want to thank someone up above for the great bounty we enjoy as voracious consumers and transmitters of data, video, images, news, music, and money, the heavens are exactly where to look.

Powered by Livefyre